@@ -4,3 +4,10 @@ from rastervision.core.analyzer.analyzer import *
 from rastervision.core.analyzer.analyzer_config import *
 from rastervision.core.analyzer.stats_analyzer import *
 from rastervision.core.analyzer.stats_analyzer_config import *
+
+__all__ = [
+    Analyzer.__name__,
+    AnalyzerConfig.__name__,
+    StatsAnalyzer.__name__,
+    StatsAnalyzerConfig.__name__,
+]
