@@ -2,3 +2,8 @@
 
 from rastervision.core.backend.backend import *
 from rastervision.core.backend.backend_config import *
+
+__all__ = [
+    Backend.__name__,
+    BackendConfig.__name__,
+]
