@@ -1,6 +1,6 @@
 # flake8: noqa
 
-from rastervision.core.data.activate_mixin import *
+from rastervision.core.data.class_config import *
 from rastervision.core.data.raster_source import *
 from rastervision.core.data.crs_transformer import *
 from rastervision.core.data.label import *
@@ -9,7 +9,7 @@ from rastervision.core.data.label_source import *
 from rastervision.core.data.label_store import *
 from rastervision.core.data.scene import *
 from rastervision.core.data.scene_config import *
-from rastervision.core.data.dataset import *
 from rastervision.core.data.dataset_config import *
-from rastervision.core.data.class_config import *
 from rastervision.core.data.raster_transformer import *
+from rastervision.core.data.vector_transformer import *
+from rastervision.core.data.utils import *
