@@ -3,3 +3,9 @@
 from rastervision.core.data.crs_transformer.crs_transformer import *
 from rastervision.core.data.crs_transformer.identity_crs_transformer import *
 from rastervision.core.data.crs_transformer.rasterio_crs_transformer import *
+
+__all__ = [
+    CRSTransformer.__name__,
+    RasterioCRSTransformer.__name__,
+    IdentityCRSTransformer.__name__,
+]
