@@ -6,6 +6,16 @@ from rastervision.core.data.label_source.chip_classification_label_source import
 from rastervision.core.data.label_source.chip_classification_label_source_config import *
 from rastervision.core.data.label_source.semantic_segmentation_label_source import *
 from rastervision.core.data.label_source.semantic_segmentation_label_source_config import *
-from rastervision.core.data.label_source.segmentation_class_transformer import *
 from rastervision.core.data.label_source.object_detection_label_source import *
 from rastervision.core.data.label_source.object_detection_label_source_config import *
+
+__all__ = [
+    LabelSource.__name__,
+    LabelSourceConfig.__name__,
+    SemanticSegmentationLabelSource.__name__,
+    SemanticSegmentationLabelSourceConfig.__name__,
+    ChipClassificationLabelSource.__name__,
+    ChipClassificationLabelSourceConfig.__name__,
+    ObjectDetectionLabelSource.__name__,
+    ObjectDetectionLabelSourceConfig.__name__,
+]
