@@ -1,5 +1,4 @@
 # flake8: noqa
-
 from rastervision.core.data.raster_source.raster_source import *
 from rastervision.core.data.raster_source.raster_source_config import *
 from rastervision.core.data.raster_source.rasterio_source import *
@@ -8,3 +7,15 @@ from rastervision.core.data.raster_source.rasterized_source import *
 from rastervision.core.data.raster_source.rasterized_source_config import *
 from rastervision.core.data.raster_source.multi_raster_source import *
 from rastervision.core.data.raster_source.multi_raster_source_config import *
+
+__all__ = [
+    RasterSource.__name__,
+    RasterSourceConfig.__name__,
+    RasterioSource.__name__,
+    RasterioSourceConfig.__name__,
+    RasterizedSource.__name__,
+    RasterizedSourceConfig.__name__,
+    RasterizerConfig.__name__,
+    MultiRasterSource.__name__,
+    MultiRasterSourceConfig.__name__,
+]
