@@ -1,7 +1,13 @@
 # flake8: noqa
 
-from rastervision.core.data.vector_source.geojson_vector_source import *
-from rastervision.core.data.vector_source.geojson_vector_source_config import *
 from rastervision.core.data.vector_source.vector_source import *
 from rastervision.core.data.vector_source.vector_source_config import *
-from rastervision.core.data.vector_source.class_inference import *
+from rastervision.core.data.vector_source.geojson_vector_source import *
+from rastervision.core.data.vector_source.geojson_vector_source_config import *
+
+__all__ = [
+    VectorSource.__name__,
+    VectorSourceConfig.__name__,
+    GeoJSONVectorSource.__name__,
+    GeoJSONVectorSourceConfig.__name__,
+]
