@@ -16,3 +16,22 @@ from rastervision.core.evaluation.semantic_segmentation_evaluator_config import
 from rastervision.core.evaluation.object_detection_evaluation import *
 from rastervision.core.evaluation.object_detection_evaluator import *
 from rastervision.core.evaluation.object_detection_evaluator_config import *
+
+__all__ = [
+    EvaluationItem.__name__,
+    ClassEvaluationItem.__name__,
+    Evaluator.__name__,
+    EvaluatorConfig.__name__,
+    ClassificationEvaluation.__name__,
+    ClassificationEvaluator.__name__,
+    ClassificationEvaluatorConfig.__name__,
+    ChipClassificationEvaluation.__name__,
+    ChipClassificationEvaluator.__name__,
+    ChipClassificationEvaluatorConfig.__name__,
+    SemanticSegmentationEvaluation.__name__,
+    SemanticSegmentationEvaluator.__name__,
+    SemanticSegmentationEvaluatorConfig.__name__,
+    ObjectDetectionEvaluation.__name__,
+    ObjectDetectionEvaluator.__name__,
+    ObjectDetectionEvaluatorConfig.__name__,
+]
