@@ -1,14 +1,21 @@
+from typing import TYPE_CHECKING, List, Optional
 from os.path import join
-import zipfile
 import logging
 
-from rastervision.pipeline import rv_config
+from rastervision.pipeline import rv_config_ as rv_config
 from rastervision.pipeline.config import (build_config, upgrade_config)
 from rastervision.pipeline.file_system.utils import (download_if_needed,
-                                                     make_dir, file_to_json)
+                                                     file_to_json, unzip)
 from rastervision.core.data.raster_source import ChannelOrderError
+from rastervision.core.data import (SemanticSegmentationLabelStoreConfig,
+                                    PolygonVectorOutputConfig,
+                                    StatsTransformerConfig)
 from rastervision.core.analyzer import StatsAnalyzerConfig
 
+if TYPE_CHECKING:
+    from rastervision.core.rv_pipeline import RVPipelineConfig
+    from rastervision.core.data import SceneConfig
+
 log = logging.getLogger(__name__)
 
 
@@ -16,10 +23,11 @@ class Predictor():
     """Class for making predictions based off of a model bundle."""
 
     def __init__(self,
-                 model_bundle_uri,
-                 tmp_dir,
-                 update_stats=False,
-                 channel_order=None):
+                 model_bundle_uri: str,
+                 tmp_dir: str,
+                 update_stats: bool = False,
+                 channel_order: Optional[List[int]] = None,
+                 scene_group: Optional[str] = None):
         """Creates a new Predictor.
 
         Args:
@@ -37,19 +45,17 @@ class Predictor():
         self.update_stats = update_stats
         self.model_loaded = False
 
-        bundle_path = download_if_needed(model_bundle_uri, tmp_dir)
+        bundle_path = download_if_needed(model_bundle_uri)
         bundle_dir = join(tmp_dir, 'bundle')
-        make_dir(bundle_dir)
-        with zipfile.ZipFile(bundle_path, 'r') as bundle_zip:
-            bundle_zip.extractall(path=bundle_dir)
+        unzip(bundle_path, bundle_dir)
 
         config_path = join(bundle_dir, 'pipeline-config.json')
         config_dict = file_to_json(config_path)
         rv_config.set_everett_config(
             config_overrides=config_dict.get('rv_config'))
         config_dict = upgrade_config(config_dict)
-        self.config = build_config(config_dict)
-        self.scene = self.config.dataset.validation_scenes[0]
+        self.config: 'RVPipelineConfig' = build_config(config_dict)
+        self.scene: 'SceneConfig' = self.config.dataset.validation_scenes[0]
 
         if not hasattr(self.scene.raster_source, 'uris'):
             raise Exception(
@@ -60,6 +66,13 @@ class Predictor():
                 'label_store in model bundle must have uri as field')
 
         for t in self.scene.raster_source.transformers:
+            if isinstance(t, StatsTransformerConfig):
+                if scene_group is not None:
+                    t.scene_group = scene_group
+                else:
+                    log.warn(f'Using stats for scene group "{t.scene_group}". '
+                             'To use a different scene group, specify '
+                             '--scene-group <scene-group-name>.')
             t.update_root(bundle_dir)
 
         if self.update_stats:
@@ -69,6 +82,7 @@ class Predictor():
 
         self.scene.label_source = None
         self.scene.aoi_uris = None
+
         self.config.dataset.train_scenes = [self.scene]
         self.config.dataset.validation_scenes = [self.scene]
         self.config.dataset.test_scenes = []
@@ -79,7 +93,7 @@ class Predictor():
 
         self.pipeline = None
 
-    def predict(self, image_uris, label_uri, vector_label_uri=None):
+    def predict(self, image_uris: List[str], label_uri: str) -> None:
         """Generate predictions for the given image.
 
         Args:
@@ -87,8 +101,6 @@ class Predictor():
                 This can be any type of URI readable by Raster Vision
                 FileSystems.
             label_uri: URI to save labels off into
-            vector_label_uri: URI to save vectorized labels for semantic segmentation
-                model bundles that support it
         """
         if self.pipeline is None:
             self.scene.raster_source.uris = image_uris
@@ -97,23 +109,22 @@ class Predictor():
                 raise Exception(
                     'pipeline in model bundle must have predict method')
 
-        try:
-            self.scene.raster_source.uris = image_uris
-            self.scene.label_store.uri = label_uri
-            if (hasattr(self.scene.label_store, 'vector_output')
-                    and self.scene.label_store.vector_output):
-                if vector_label_uri:
-                    for vo in self.scene.label_store.vector_output:
-                        vo.uri = join(
-                            vector_label_uri, '{}-{}.json'.format(
-                                vo.class_id, vo.get_mode()))
-                else:
-                    self.scene.label_store.vector_output = []
-            elif vector_label_uri:
-                log.warn(
-                    'vector_label_uri was supplied but this model bundle does not '
-                    'generate vector labels.')
+        self.scene.raster_source.uris = image_uris
+        self.scene.label_store.uri = label_uri
 
+        if isinstance(self.scene.label_store,
+                      SemanticSegmentationLabelStoreConfig):
+            # create vector outputs for each class without specifying URIs
+            self.scene.label_store.vector_output = [
+                PolygonVectorOutputConfig(class_id=i)
+                for i, _ in enumerate(self.config.dataset.class_config.names)
+            ]
+            # set URIs
+            self.scene.label_store.uri = label_uri
+            for vo in self.scene.label_store.vector_output:
+                vo.update(self.config, self.scene, uri_prefix=label_uri)
+
+        try:
             if self.update_stats:
                 self.pipeline.analyze()
             self.pipeline.predict()
